/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2002, 2006 All Rights Reserved.
 * (C) Copyright Webify Solutions, Inc. 2002, 2006 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.fabric.hc.context.extractor;

import com.ibm.websphere.fabric.da.PendingRequest;
import com.ibm.websphere.fabric.da.context.Context;
import com.ibm.websphere.fabric.da.plugin.ContextExtractor;
import com.ibm.websphere.fabric.da.plugin.UnexpectedContentException;
import com.ibm.websphere.fabric.da.types.TypedValue;
import com.ibm.websphere.fabric.hc.util.BPELUtility;
import commonj.sdo.DataObject;
import commonj.sdo.Sequence;

/**
 * Sets the LOB assertion for the current interface.
 * 
 * @author sjignesh
 */
public class LOBAssertionPolicyContextExtractorImpl implements ContextExtractor {

	/**
	 * URI for LOB based assertion.
	 */
	private static final String LOB_TYPE_ASSERTION_ELEMENT = "http://www.ibm.com/websphere/fabric/healthcare/payor/ext/assertion#lineOfBusiness";

	private static final String FABRIC_GOVERNANCE = "fc://fabric/governance/fabricproject-inst#0dceb16c-bafa-473f-b289-39897c8225a6";

	private static final String FABRIC_GOVERNANCE_VALUE = "http://www.webifysolutions.com/2005/10/catalog/governance#FabricProject";

	/**
	 * Default constructor.
	 */
	public LOBAssertionPolicyContextExtractorImpl() {
		super();
	}

	/**
	 * @see com.ibm.websphere.fabric.da.plugin.ContextExtractor#
	 *      extractContext(com.ibm.websphere.fabric.da.PendingRequest)
	 */
	public Context extractContext(PendingRequest req)
			throws UnexpectedContentException {
		boolean governanceFabricProject = false;
		Context context = req.getContext();
		Sequence sequence = (Sequence) req.getFirstBodyElement().get(0);
		DataObject requestDataObject = (DataObject) sequence.getValue(0);

		String memberId = requestDataObject.getString("memberId");

		TypedValue assertionValue = new TypedValue(BPELUtility
				.getLOBAssertion(memberId));
		context
				.setSelectionProperty(LOB_TYPE_ASSERTION_ELEMENT,
						assertionValue);

		TypedValue governanceFabricProjectValue = new TypedValue(
				FABRIC_GOVERNANCE);

		context.setSelectionProperty(FABRIC_GOVERNANCE_VALUE,
				governanceFabricProjectValue);
		return context;
	}

}