/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2009 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.healthcare.extractor;

import com.ibm.websphere.fabric.da.PendingRequest;
import com.ibm.websphere.fabric.da.context.Context;
import com.ibm.websphere.fabric.da.plugin.ContextExtractor;
import com.ibm.websphere.fabric.da.plugin.UnexpectedContentException;
import com.ibm.websphere.fabric.da.types.TypedValue;
import com.ibm.websphere.sca.ServiceManager;

public class LineOfBusinessExtractorImpl implements ContextExtractor {

	/**
	 * URI for LOB based assertion.
	 */
	private static final String LOB_TYPE_ASSERTION_ELEMENT = "http://www.ibm.com/websphere/fabric/healthcare/payor/ext/assertion#lineOfBusiness";

	private static final String FABRIC_GOVERNANCE = "fc://fabric/governance/fabricproject-inst#c4a615f9-0ecd-451f-9486-a72af9676824";

	private static final String FABRIC_GOVERNANCE_VALUE = "http://www.webifysolutions.com/2005/10/catalog/governance#FabricProject";

	/**
	 * Default constructor.
	 */
	public LineOfBusinessExtractorImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private ContextExtractor getMyService() {
		return (ContextExtractor) ServiceManager.INSTANCE.locateService("self");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seecom.ibm.websphere.fabric.da.plugin.ContextExtractor#extractContext(
	 * PendingRequest arg0)
	 */
	public Context extractContext(PendingRequest req)
			throws UnexpectedContentException {
		Context context = req.getContext();
		String memberId = (String) req.getFirstBodyElement().get(0);
		TypedValue assertionValue = new TypedValue(getLOBAssertion(memberId));
		context
				.setSelectionProperty(LOB_TYPE_ASSERTION_ELEMENT,
						assertionValue);
		TypedValue governanceFabricProjectValue = new TypedValue(
				FABRIC_GOVERNANCE);
		context.setSelectionProperty(FABRIC_GOVERNANCE_VALUE,
				governanceFabricProjectValue);
		return context;
	}

	/**
	 * Determines the LOB based on the memberId.
	 * 
	 */
	private String getLOBAssertion(String memberId) {
		String lob = "IND";
		if (memberId != null) {
			if ("MED".equals(memberId.substring(0, 3))) {
				lob = "MED";
			} else if ("GRP".equals(memberId.substring(0, 3))) {
				lob = "GRP";
			} else if ("DEN".equals(memberId.substring(0, 3))) {
				lob = "DEN";
			}
		}
		return lob;
	}
}